@@ -102,25 +102,29 @@ class visualize_activations(object):
             self.pad_width = (self.image.shape[-3], self.image.shape[-2], self.image.shape[-1])  
             self.yololoss = volume_yolo_loss(self.categories, self.gridx, self.gridy, self.gridz, self.nboxes,
                                             self.box_vector, self.entropy)
-            self.model = NEATVollNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
+            self.model = load_model(os.path.join(self.model_dir, self.model_name) + '.h5',
+                                custom_objects={'loss': volume_yolo_loss, 'Concat': Concat})
         
         if self.oneat_tresnet:
             self.pad_width = (self.image.shape[-3], self.image.shape[-2], self.image.shape[-1]) 
             self.yololoss = static_yolo_loss(self.categories, self.gridx, self.gridy, self.nboxes, self.box_vector,
                                                         self.entropy)
-            self.model = NEATTResNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
+            self.model = load_model(os.path.join(self.model_dir, self.model_name) + '.h5',
+                                custom_objects={'loss': static_yolo_loss, 'Concat': Concat})
         
         if self.oneat_lrnet:
             self.pad_width = (self.image.shape[-3], self.image.shape[-2], self.image.shape[-1]) 
-            self.yololoss = dynamic_yolo_loss(self.categories, self.gridx, self.gridy, self.gridt, self.nboxes,
+            self.yololoss = dynamic_yolo_loss(self.categories, self.gridx, self.gridy, 1, self.nboxes,
                                           self.box_vector, self.entropy)
-            self.model = NEATLRNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
+            self.model = load_model(os.path.join(self.model_dir, self.model_name) + '.h5',
+                                custom_objects={'loss': dynamic_yolo_loss, 'Concat': Concat})
 
         if self.oneat_resnet:
             self.pad_width = (self.image.shape[-2], self.image.shape[-1]) 
             self.yololoss = static_yolo_loss(self.categories, self.gridx, self.gridy, self.nboxes, self.box_vector,
                                                         self.entropy)
-            self.model = NEATResNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
+            self.model = load_model(os.path.join(self.model_dir, self.model_name) + '.h5',
+                                custom_objects={'loss': static_yolo_loss, 'Concat': Concat})
 
         elif self.voll_starnet_2D:
                 if len(self.image.shape) == 4:
@@ -161,6 +165,7 @@ class visualize_activations(object):
         viz_box = VisualizeBoxes(viewer = self.viewer, key_categories = self.key_categories, event_threshold = self.event_threshold)
         
         if self.oneat_vollnet:
+             self.model = NEATVollNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
              marker_tree =  self.model.get_markers(self.imagename, self.segdir)
                                    
              self.model.predict(self.imagename,
@@ -173,6 +178,7 @@ class visualize_activations(object):
              viz_box.create_volume_boxes(iou_classedboxes = self.model.iou_classedboxes)
              
         if self.oneat_lrnet:
+            self.model = NEATLRNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
             marker_tree =  self.model.get_markers(self.imagename, 
                                                 self.segdir,
                                                 start_project_mid = self.start_project_mid,
@@ -190,6 +196,7 @@ class visualize_activations(object):
             viz_box.create_volume_boxes(iou_classedboxes = self.model.iou_classedboxes, volumetric = False, shape = self.model.image.shape)
             
         if self.oneat_tresnet:
+            self.model = NEATTResNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
             marker_tree = self.model.get_markers( self.imagename, 
                                                   self.segdir, 
                                                   start_project_mid = self.start_project_mid,
@@ -207,6 +214,7 @@ class visualize_activations(object):
             
         if self.oneat_resnet:
             
+            self.model = NEATResNet(None, self.model_dir , self.model_name, self.catconfig, self.cordconfig)
             self.model.predict(self.imagename,
                                event_threshold = self.event_threshold,
                                event_confidence = self.event_confidence,
